@@ -3,7 +3,6 @@ package tfexec
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"reflect"
@@ -21,7 +20,7 @@ func TestTerraformCLIPlan(t *testing.T) {
 		for _, arg := range args {
 			if strings.HasPrefix(arg, "-out=") {
 				planFile := arg[len("-out="):]
-				return ioutil.WriteFile(planFile, plan.Bytes(), 0600)
+				return os.WriteFile(planFile, plan.Bytes(), 0600)
 			}
 		}
 		return fmt.Errorf("failed to find -out= option: %v", args)
