@@ -2,7 +2,7 @@ package tfexec
 
 import (
 	"context"
-	"io/ioutil"
+	"os"
 	"reflect"
 	"regexp"
 	"sort"
@@ -21,14 +21,14 @@ func TestTerraformCLIStateMv(t *testing.T) {
 		for _, arg := range args {
 			if strings.HasPrefix(arg, "-state=") {
 				stateFile := arg[len("-state="):]
-				err := ioutil.WriteFile(stateFile, updatedState.Bytes(), 0600)
+				err := os.WriteFile(stateFile, updatedState.Bytes(), 0600)
 				if err != nil {
 					return err
 				}
 			}
 			if strings.HasPrefix(arg, "-state-out=") {
 				stateOutFile := arg[len("-state-out="):]
-				err := ioutil.WriteFile(stateOutFile, updatedStateOut.Bytes(), 0600)
+				err := os.WriteFile(stateOutFile, updatedStateOut.Bytes(), 0600)
 				if err != nil {
 					return err
 				}
